#
# spec file for package python-modernize
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-modernize
Version:        0.8.0
Release:        2.14
Summary:        A tool for modernizing Python code using lib2to3
License:        BSD-3-Clause AND Python-2.0
URL:            https://github.com/PyCQA/modernize
Source:         https://github.com/PyCQA/modernize/archive/v%{version}.tar.gz#/modernize-%{version}.tar.gz
BuildRequires:  %{python_module fissix}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-dbm
Requires:       python-fissix
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module dbm}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A hack on top of fissix for modernizing Python code.

%prep
%setup -q -n modernize-%{version}
# disable pytest-cov
sed -i 's/"--cov.*",//g' pyproject.toml

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/modernize
%python_clone -a %{buildroot}%{_bindir}/python-modernize
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# ensure that pickled cache files from fissix don't interfere between flavors
%python_expand mkdir build/cache
export XDG_CACHE_HOME=$PWD/build/cache
%pytest

%post
%python_install_alternative modernize
%python_install_alternative python-modernize

%postun
%python_uninstall_alternative modernize
%python_uninstall_alternative python-modernize

%files %{python_files}
%doc CHANGELOG.rst README.rst
%license LICENSE
%python_alternative %{_bindir}/modernize
%python_alternative %{_bindir}/python-modernize
%{python_sitelib}/libmodernize
%{python_sitelib}/modernize.py
%pycache_only %{python_sitelib}/__pycache__/modernize.*.pyc
%{python_sitelib}/modernize-%{version}*-info

%changelog
* Sat Dec 25 2021 Ben Greiner <code@bnavigator.de>
- ensure that pickled cache files from fissix don't interfere
  between flavor tests
* Mon Oct 12 2020 Marketa Calabkova <mcalabkova@suse.com>
- Do not use nonsense config options
* Sat Oct 10 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v0.8.0
  * add ``modernize`` console_script
  * use ``fissix`` instead of deprecated `lib2to3`
    modernize itself will no-longer run under Python 2, or Python <3.6,
    but will always be able to process Python 2 code.
  * Fix for dict.viewitems(), dict.iteritems() etc in chained calls
  * Fix for SLASHEQUAL ``/=`` in fix_classic_divivion
  * Fix typo in help string for --enforce option
  * move project to https://github.com/PyCQA/modernize/
* Sun Aug 16 2020 John Vandenberg <jayvdb@gmail.com>
- Replace nose with pytest
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Jan  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use python dbm dependency instead of legacy gdbm
* Sat Mar 30 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.7
